Index: zaptel.c
===================================================================
RCS file: /usr/cvsroot/zaptel/zaptel.c,v
retrieving revision 1.84
diff -u -r1.84 zaptel.c
--- zaptel.c	2 Jul 2004 13:04:54 -0000	1.84
+++ zaptel.c	15 Jul 2004 14:14:18 -0000
@@ -143,6 +143,12 @@
 static devfs_handle_t ctl;
 static devfs_handle_t timer;
 #endif
+
+/* udev necessary data structures.  Yeah! */
+#ifdef CONFIG_ZAP_UDEV
+static struct class_simple *zap_class = NULL;
+#endif
+
 /* There is a table like this in the PPP driver, too */
 
 static int deftaps = 64;
@@ -4165,6 +4171,14 @@
 	}
 #endif /* CONFIG_DEVFS_FS */
 
+#ifdef CONFIG_ZAP_UDEV
+	for (x = 0; x < span->channels; x++) {
+		char chan_name[50];
+		sprintf(chan_name, "zap%d", span->chans[x].channo);
+		class_simple_device_add(zap_class, MKDEV(ZT_MAJOR, span->chans[x].channo), NULL, chan_name);
+	}
+#endif /* CONFIG_ZAP_UDEV */
+
 	if (debug)
 		printk("Registered Span %d ('%s') with %d channels\n", span->spanno, span->name, span->channels);
 	if (!master || prefmaster) {
@@ -4208,6 +4222,13 @@
 	}
 	devfs_unregister(span->dhandle);
 #endif /* CONFIG_DEVFS_FS */
+
+#ifdef CONFIG_ZAP_UDEV
+	for (x = 0; x < span->channels; x++) {
+		class_simple_device_remove(MKDEV(ZT_MAJOR, span->chans[x].channo));
+	}
+#endif /* CONFIG_ZAP_UDEV */
+
 	spans[span->spanno] = NULL;
 	span->spanno = 0;
 	span->flags &= ~ZT_FLAG_REGISTERED;
@@ -6078,6 +6099,15 @@
 #ifdef CONFIG_PROC_FS
 	proc_entries[0] = proc_mkdir("zaptel", NULL);
 #endif
+
+#ifdef CONFIG_ZAP_UDEV /* udev support functions */
+	zap_class = class_simple_create(THIS_MODULE, "zaptel");
+	class_simple_device_add(zap_class, MKDEV(ZT_MAJOR, 253), NULL, "zaptimer");
+	class_simple_device_add(zap_class, MKDEV(ZT_MAJOR, 254), NULL, "zapchannel");
+	class_simple_device_add(zap_class, MKDEV(ZT_MAJOR, 255), NULL, "zappseudo");
+	class_simple_device_add(zap_class, MKDEV(ZT_MAJOR, 0), NULL, "zapctl");
+#endif /* CONFIG_ZAP_UDEV */
+
 #ifdef CONFIG_DEVFS_FS
 	{
 	umode_t mode = S_IFCHR|S_IRUGO|S_IWUGO;
@@ -6127,6 +6157,13 @@
 	devfs_unregister(zaptel_devfs_dir);
 	devfs_unregister_chrdev(ZT_MAJOR, "zaptel");
 #else
+#ifdef CONFIG_ZAP_UDEV
+	class_simple_device_remove(MKDEV(ZT_MAJOR, 253)); /* timer */
+	class_simple_device_remove(MKDEV(ZT_MAJOR, 254)); /* channel */
+	class_simple_device_remove(MKDEV(ZT_MAJOR, 255)); /* pseudo */
+	class_simple_device_remove(MKDEV(ZT_MAJOR, 0)); /* ctl */
+	class_simple_destroy(zap_class);
+#endif /* CONFIG_ZAP_UDEV */
 	unregister_chrdev(ZT_MAJOR, "zaptel");
 #endif
 #ifdef CONFIG_ZAPTEL_WATCHDOG
Index: zconfig.h
===================================================================
RCS file: /usr/cvsroot/zaptel/zconfig.h,v
retrieving revision 1.10
diff -u -r1.10 zconfig.h
--- zconfig.h	2 Jul 2004 13:04:54 -0000	1.10
+++ zconfig.h	15 Jul 2004 14:14:18 -0000
@@ -115,5 +115,10 @@
  */
 /* #define CONFIG_CAC_GROUNDSTART */
 
+/* 
+ * Uncomment to add EXPERIMENTAL support for udev
+ */
+/* #define CONFIG_ZAP_UDEV */
+
 
 #endif
